api.system.notification.v1.test_helpers.rule package — Argus-Toolbelt 1.0 documentation

# api.system.notification.v1.test_helpers.rule package

## Submodules

## api.system.notification.v1.test_helpers.rule.add_action module

`api.system.notification.v1.test_helpers.rule.add_action.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.add_action.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.add_action.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.add_action.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.add_destination module

`api.system.notification.v1.test_helpers.rule.add_destination.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.add_destination.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.add_destination.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.add_destination.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.create module

`api.system.notification.v1.test_helpers.rule.create.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.create.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.create.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.create.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.delete_action module

`api.system.notification.v1.test_helpers.rule.delete_action.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.delete_action.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.delete_action.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.delete_action.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.delete_destination module

`api.system.notification.v1.test_helpers.rule.delete_destination.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.delete_destination.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.delete_destination.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.delete_destination.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.delete_rule module

`api.system.notification.v1.test_helpers.rule.delete_rule.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.delete_rule.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.delete_rule.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.delete_rule.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.duplicate_rule module

`api.system.notification.v1.test_helpers.rule.duplicate_rule.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/duplicate, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.duplicate_rule.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/duplicate, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.duplicate_rule.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/duplicate, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.duplicate_rule.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/duplicate, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.get_rule_by_id module

`api.system.notification.v1.test_helpers.rule.get_rule_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.get_rule_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.get_rule_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.get_rule_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.get_rule_by_name module

`api.system.notification.v1.test_helpers.rule.get_rule_by_name.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.get_rule_by_name.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.get_rule_by_name.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.get_rule_by_name.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.list module

`api.system.notification.v1.test_helpers.rule.list.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/search, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.list.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/search, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.list.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/search, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.list.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/search, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.revisions module

`api.system.notification.v1.test_helpers.rule.revisions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/revisions, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.revisions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/revisions, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.revisions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/revisions, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.revisions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/revisions, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.update_action module

`api.system.notification.v1.test_helpers.rule.update_action.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.update_action.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.update_action.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.update_action.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/actions/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.update_destination module

`api.system.notification.v1.test_helpers.rule.update_destination.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.update_destination.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.update_destination.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.update_destination.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+/destinations/w+, respond with HTTP 401

## api.system.notification.v1.test_helpers.rule.update_rule module

`api.system.notification.v1.test_helpers.rule.update_rule.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 403

`api.system.notification.v1.test_helpers.rule.update_rule.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 404

`api.system.notification.v1.test_helpers.rule.update_rule.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 200

`api.system.notification.v1.test_helpers.rule.update_rule.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/notification/v1/rule/w+, respond with HTTP 401

## Module contents